@@ -84,7 +84,7 @@
 /* Things with external linkage
    ============================ */
 
-chararray_t	g_swircVersion	= "v3.4.2";
+chararray_t	g_swircVersion	= "v3.4.3";
 chararray_t	g_swircYear	= "2012-2023";
 chararray_t	g_swircAuthor	= "Markus Uhlin";
 chararray_t	g_swircWebAddr	= "https://www.nifty-networks.net/swirc/";
@@ -762,17 +762,30 @@ get_locale_info(int category)
 	return (li);
 }
 
+locale_info::~locale_info()
+{
+	free(this->lang_and_territory);
+	free(this->codeset);
+}
+
 /**
  * Free locale info
  */
 void
 free_locale_info(struct locale_info *li)
 {
-	if (li) {
-		free(li->lang_and_territory);
-		free(li->codeset);
-		delete li;
-	}
+	delete li;
+}
+
+cmdline_opt_values::~cmdline_opt_values()
+{
+	free(this->server);
+	free(this->port);
+	free(this->nickname);
+	free(this->username);
+	free(this->rl_name);
+	free(this->hostname);
+	free(this->config_file);
 }
 
 /**
@@ -781,15 +794,8 @@ free_locale_info(struct locale_info *li)
 void
 cmdline_options_destroy(void)
 {
-	free_and_null(&g_cmdline_opts->server);
-	free_and_null(&g_cmdline_opts->port);
-	free_and_null(&g_cmdline_opts->nickname);
-	free_and_null(&g_cmdline_opts->username);
-	free_and_null(&g_cmdline_opts->rl_name);
-	free_and_null(&g_cmdline_opts->hostname);
-	free_and_null(&g_cmdline_opts->config_file);
-
 	delete g_cmdline_opts;
+	g_cmdline_opts = NULL;
 }
 
 void
