@@ -69,8 +69,6 @@
 #define WATTR_ON(win, attrs)  ((void) wattr_on(win, attrs, NULL))
 #define WCOLOR_SET(win, cpn)  ((void) wcolor_set(win, cpn, NULL))
 
-#define STRLEN_CAST(string) strlen(reinterpret_cast<CSTRING>(string))
-
 /****************************************************************
 *                                                               *
 *  ------------------ Structure definitions ------------------  *
@@ -78,8 +76,22 @@
 ****************************************************************/
 
 struct message_components {
-	char	*text;
+	STRING	 text;
 	int	 indent;
+
+	message_components()
+	    : text(NULL)
+	    , indent(0)
+	{}
+	message_components(STRING p_text, int p_indent)
+	    : text(p_text)
+	    , indent(p_indent)
+	{}
+	~message_components()
+	{
+		free(this->text);
+		this->text = NULL;
+	}
 };
 
 struct text_decoration_bools {
@@ -89,17 +101,23 @@ struct text_decoration_bools {
 	bool	 is_reverse;
 	bool	 is_underline;
 
-	text_decoration_bools();
-};
+	text_decoration_bools() : is_blink(false)
+	    , is_bold(false)
+	    , is_color(false)
+	    , is_reverse(false)
+	    , is_underline(false)
+	{}
 
-text_decoration_bools::text_decoration_bools()
-{
-	this->is_blink     = false;
-	this->is_bold      = false;
-	this->is_color     = false;
-	this->is_reverse   = false;
-	this->is_underline = false;
-}
+	void
+	reset(void)
+	{
+		this->is_blink		= false;
+		this->is_bold		= false;
+		this->is_color		= false;
+		this->is_reverse	= false;
+		this->is_underline	= false;
+	}
+};
 
 struct case_default_context {
 	WINDOW		*win;
@@ -109,36 +127,32 @@ struct case_default_context {
 	int		 max_lines;
 	ptrdiff_t	 diff;
 
-	case_default_context();
-	case_default_context(WINDOW *, wchar_t, bool, int, int, ptrdiff_t);
+	case_default_context() : win(NULL)
+	    , wc(L'\0')
+	    , nextchar_empty(false)
+	    , indent(0)
+	    , max_lines(0)
+	    , diff(0)
+	{
+		/* empty */;
+	}
+
+	case_default_context(WINDOW *p_win,
+	    wchar_t p_wc,
+	    bool p_nextchar_empty,
+	    int p_indent,
+	    int p_max_lines,
+	    ptrdiff_t p_diff) : win(p_win)
+	    , wc(p_wc)
+	    , nextchar_empty(p_nextchar_empty)
+	    , indent(p_indent)
+	    , max_lines(p_max_lines)
+	    , diff(p_diff)
+	{
+		/* empty */;
+	}
 };
 
-case_default_context::case_default_context()
-{
-	this->win            = NULL;
-	this->wc             = 0L;
-	this->nextchar_empty = false;
-	this->indent         = 0;
-	this->max_lines      = 0;
-	this->diff           = 0;
-}
-
-case_default_context::case_default_context(
-	WINDOW		*win,
-	wchar_t		 wc,
-	bool		 nextchar_empty,
-	int		 indent,
-	int		 max_lines,
-	ptrdiff_t	 diff)
-{
-	this->win            = win;
-	this->wc             = wc;
-	this->nextchar_empty = nextchar_empty;
-	this->indent         = indent;
-	this->max_lines      = max_lines;
-	this->diff           = diff;
-}
-
 /****************************************************************
 *                                                               *
 *  -------------- Objects with external linkage --------------  *
@@ -245,6 +259,9 @@ static struct ptext_colorMap_tag {
 *                                                               *
 ****************************************************************/
 
+static size_t	 get_mb_strlen(CSTRING) PTR_ARGS_NONNULL;
+static char	*get_buffer(CSTRING) PTR_ARGS_NONNULL;
+
 static void
 addmbs(WINDOW *win, const unsigned char *mbs)
 {
@@ -315,10 +332,11 @@ case_bold(WINDOW *win, bool *is_bold)
  * free()'d.
  *
  * @param wc Wide-character
+ * @param bytes_out How many bytes is the wc?
  * @return The result
  */
 static unsigned char *
-convert_wc(wchar_t wc)
+convert_wc(wchar_t wc, size_t &bytes_out)
 {
 	const size_t	 size = MB_LEN_MAX;
 	mbstate_t	 ps;
@@ -337,6 +355,7 @@ convert_wc(wchar_t wc)
 		if (wc != L'\0')
 			err_log(errno, "printtext: %s: wcrtomb_s", __func__);
 		*mbs = '\0';
+		bytes_out = 0;
 		return mbs;
 	}
 #else
@@ -347,11 +366,13 @@ convert_wc(wchar_t wc)
 		if (wc != L'\0')
 			err_log(EILSEQ, "printtext: %s: wcrtomb", __func__);
 		*mbs = '\0';
+		bytes_out = 0;
 		return mbs;
 	}
 #endif
 
 	mbs[bytes_written] = '\0';
+	bytes_out = bytes_written;
 	return static_cast<unsigned char *>(xrealloc(mbs, bytes_written + 1));
 }
 
@@ -370,14 +391,15 @@ putbyte(char *cp, const unsigned char b)
 static cc_check_t
 check_for_part1(wchar_t **bufp, char *fg)
 {
-	unsigned char *mbs;
+	size_t		 bytes_out = 0;
+	unsigned char	*mbs;
 
 	if (!*++(*bufp))
 		return BUF_EOF;
 
-	mbs = convert_wc(**bufp);
+	mbs = convert_wc(**bufp, bytes_out);
 
-	if (STRLEN_CAST(mbs) != 1 || !sw_isdigit(*mbs)) {
+	if (bytes_out != 1 || !sw_isdigit(*mbs)) {
 		--(*bufp);
 		free(mbs);
 		return STOP_INTERPRETING;
@@ -397,14 +419,15 @@ check_for_part1(wchar_t **bufp, char *fg)
 static cc_check_t
 check_for_part2(wchar_t **bufp, char *fg, bool *has_comma)
 {
-	unsigned char *mbs;
+	size_t		 bytes_out = 0;
+	unsigned char	*mbs;
 
 	if (!*++(*bufp))
 		return BUF_EOF;
 
-	mbs = convert_wc(**bufp);
+	mbs = convert_wc(**bufp, bytes_out);
 
-	if (STRLEN_CAST(mbs) != 1 || (!sw_isdigit(*mbs) && *mbs != ',')) {
+	if (bytes_out != 1 || (!sw_isdigit(*mbs) && *mbs != ',')) {
 		--(*bufp);
 		free(mbs);
 		return STOP_INTERPRETING;
@@ -429,14 +452,15 @@ check_for_part2(wchar_t **bufp, char *fg, bool *has_comma)
 static cc_check_t
 check_for_part3(wchar_t **bufp, bool *has_comma, bool fg_complete, char *bg)
 {
-	unsigned char *mbs;
+	size_t		 bytes_out = 0;
+	unsigned char	*mbs;
 
 	if (!*++(*bufp))
 		return BUF_EOF;
 
-	mbs = convert_wc(**bufp);
+	mbs = convert_wc(**bufp, bytes_out);
 
-	if (STRLEN_CAST(mbs) != 1 || (*mbs != ',' && !sw_isdigit(*mbs))) {
+	if (bytes_out != 1 || (*mbs != ',' && !sw_isdigit(*mbs))) {
 		--(*bufp);
 		free(mbs);
 		return STOP_INTERPRETING;
@@ -469,14 +493,15 @@ check_for_part3(wchar_t **bufp, bool *has_comma, bool fg_complete, char *bg)
 static cc_check_t
 check_for_part4(wchar_t **bufp, bool got_digit_bg, char *bg)
 {
-	unsigned char *mbs;
+	size_t		 bytes_out = 0;
+	unsigned char	*mbs;
 
 	if (!*++(*bufp))
 		return BUF_EOF;
 
-	mbs = convert_wc(**bufp);
+	mbs = convert_wc(**bufp, bytes_out);
 
-	if (STRLEN_CAST(mbs) != 1 || !sw_isdigit(*mbs)) {
+	if (bytes_out != 1 || !sw_isdigit(*mbs)) {
 		--(*bufp);
 		free(mbs);
 		return STOP_INTERPRETING;
@@ -499,14 +524,15 @@ check_for_part4(wchar_t **bufp, bool got_digit_bg, char *bg)
 static cc_check_t
 check_for_part5(wchar_t **bufp, char *bg)
 {
-	unsigned char *mbs;
+	size_t		 bytes_out = 0;
+	unsigned char	*mbs;
 
 	if (!*++(*bufp))
 		return BUF_EOF;
 
-	mbs = convert_wc(**bufp);
+	mbs = convert_wc(**bufp, bytes_out);
 
-	if (STRLEN_CAST(mbs) != 1 || !sw_isdigit(*mbs)) {
+	if (bytes_out != 1 || !sw_isdigit(*mbs)) {
 		--(*bufp);
 		free(mbs);
 		return STOP_INTERPRETING;
@@ -653,7 +679,7 @@ case_color(WINDOW *win, bool *is_color, wchar_t **bufp)
 static void
 do_indent(WINDOW *win, const int indent, int *insert_count)
 {
-	attr_t attrs = win->_attrs;
+	const attr_t attrs = win->_attrs;
 
 	/* turn off all attributes during indentation */
 	(void) wattrset(win, A_NORMAL);
@@ -699,12 +725,14 @@ static void
 case_default(const struct case_default_context *ctx, int *rep_count,
     int *lines_count, int *insert_count)
 {
-	unsigned char *mbs;
+	size_t		 dummy;
+	unsigned char	*mbs;
 
 	if (!iswprint(ctx->wc) && ctx->wc != L'\n')
 		return;
 
-	mbs = convert_wc(ctx->wc);
+	mbs = convert_wc(ctx->wc, dummy);
+	UNUSED_VAR(dummy);
 
 	if (!is_scrollok(ctx->win)) {
 		addmbs(ctx->win, mbs);
@@ -795,8 +823,6 @@ case_underline(WINDOW *win, bool *is_underline)
 	}
 }
 
-static size_t get_mb_strlen(CSTRING) PTR_ARGS_NONNULL;
-
 /**
  * Get multibyte string length
  */
@@ -849,13 +875,9 @@ set_indent(int *indent, CSTRING fmt, ...)
  */
 static struct message_components *
 get_processed_out_message(CSTRING unproc_msg, enum message_specifier_type
-    spec_type, bool include_ts, CSTRING srv_time)
+    spec_type, bool include_ts, CSTRING srv_time) noexcept
 {
-	struct message_components *pout =
-	    static_cast<struct message_components *>(xcalloc(sizeof *pout, 1));
-
-	pout->text = NULL;
-	pout->indent = 0;
+	struct message_components *pout = new message_components(NULL, 0);
 
 	if (include_ts) {
 		STRING ts = NULL;
@@ -1010,8 +1032,8 @@ windows_convert_to_utf8(CSTRING buf)
 static wchar_t *
 try_convert_buf_with_cs(CSTRING buf, CSTRING codeset)
 {
-	char			*original_locale = NULL;
-	char			*tmp_locale = NULL;
+	STRING			 original_locale = NULL;
+	STRING			 tmp_locale = NULL;
 	struct locale_info	*li = NULL;
 	wchar_t			*out = NULL;
 
@@ -1168,22 +1190,6 @@ replace_characters_with_spaces(wchar_t *wc_buf, const wchar_t *set)
 		*wcp = L' ';
 }
 
-/**
- * Reset text-decoration bools
- *
- * @param booleans Context structure
- * @return Void
- */
-static void
-text_decoration_bools_reset(struct text_decoration_bools *booleans)
-{
-	booleans->is_blink     = false;
-	booleans->is_bold      = false;
-	booleans->is_color     = false;
-	booleans->is_reverse   = false;
-	booleans->is_underline = false;
-}
-
 /**
  * Create mutex "vprinttext_mutex".
  */
@@ -1314,6 +1320,52 @@ printtext(PPRINTTEXT_CONTEXT ctx, CSTRING fmt, ...)
 	va_end(ap);
 }
 
+#ifdef UNIT_TESTING
+void
+printtext_convert_wc_test1(void **state)
+{
+	const wchar_t array[] =
+	    L"0123456789"
+	    L"ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+	    L"abcdefghijklmnopqrstuvwxyz";
+	const size_t array_len = wcslen(array);
+
+	for (size_t i = 0; i < array_len; i++) {
+		size_t		 bytes_out = 0;
+		unsigned char	*mbs;
+
+		mbs = convert_wc(array[i], bytes_out);
+		assert_non_null(mbs);
+		assert_true(bytes_out == 1);
+		free(mbs);
+	}
+	UNUSED_PARAM(state);
+}
+
+void
+printtext_convert_wc_test2(void **state)
+{
+	const wchar_t array[] = {L'Å',L'Ä',L'Ö',L'å',L'ä',L'ö'};
+
+	for (size_t i = 0; i < ARRAY_SIZE(array); i++) {
+		size_t		 bytes_out = 0;
+		unsigned char	*mbs;
+
+		mbs = convert_wc(array[i], bytes_out);
+		assert_non_null(mbs);
+		if (!*mbs) {
+			assert_true(bytes_out == 0);
+		} else {
+			assert_true(bytes_out > 1);
+			print_message("%s: in=%lc out=%s\r\n", __func__,
+			    array[i], mbs);
+		}
+		free(mbs);
+	}
+	UNUSED_PARAM(state);
+}
+#endif // UNIT_TESTING
+
 void
 printtext_print(CSTRING what, CSTRING fmt, ...)
 {
@@ -1349,8 +1401,6 @@ printtext_print(CSTRING what, CSTRING fmt, ...)
 	printtext_context_destroy(ctx);
 }
 
-static char *get_buffer(CSTRING) PTR_ARGS_NONNULL;
-
 static char *
 get_buffer(CSTRING orig)
 {
@@ -1487,7 +1537,7 @@ printtext_puts(WINDOW *pwin, CSTRING buf, int indent, int max_lines,
 			case_color(pwin, &booleans.is_color, &wc_bufp);
 			break;
 		case NORMAL:
-			text_decoration_bools_reset(&booleans);
+			booleans.reset();
 			(void) wattrset(pwin, A_NORMAL);
 			break;
 		case REVERSE:
@@ -1624,7 +1674,6 @@ vprinttext(PPRINTTEXT_CONTEXT ctx, CSTRING fmt, va_list ap)
 	}
 
 	free(fmt_copy);
-	free(pout->text);
-	free(pout);
+	delete pout;
 	mutex_unlock(&vprinttext_mutex);
 }
